const esbuild = require('esbuild');
const { sassPlugin } = require('esbuild-sass-plugin');
const { readFileSync } = require('node:fs');
const makeDir = require('make-dir');

function buildJs() {
  esbuild.build({
    entryPoints: ['js/dist.js'],
    outfile: 'bundle/mythical-player.dist.js',
    format: 'iife',
    footer: {
      js: 'var MythicalPlayer = MythicalPlayerComponent.default'
    },
    globalName: 'MythicalPlayerComponent',
    bundle: true,
    minify: true,
    sourcemap: false,
    legalComments: 'eof',
    target: ['chrome102', 'firefox102', 'safari16'],
    plugins: [
      sassPlugin({
        filter: /\.scss$/,
        type: 'css-text'
      })
    ]
  });
}

module.exports = {
  buildJs,
  build: function () {
    async function initBuild() {
      const paths = await Promise.all([makeDir('sass/icons')]);
      console.log(paths);

      const { svgFontConjurer } = await import('svg-font-conjurer');
      svgFontConjurer({
        createExample: false,
        createFormatSvg: false,
        createFormatTtf: false,
        createFormatWoff: false,
        createBase64Exports: true,
        createFormatWoff2: true,
        fontName: 'MythicalPlayer',
        icons: JSON.parse(
          readFileSync('./icons/icon-list.json', {
            encoding: 'utf-8'
          })
        ),
        routes: {
          icons: './icons/current',
          fonts: './js/fonts',
          scss: {
            path: './sass/icons',
            name: {
              variables: 'variables-icons-mythical-player',
              mixinItem: 'icon-item',
              mixinUnicode: 'unicode',
              list: 'list-icons-mythical-player'
            }
          },
          example: './src/apps/player/icons/example'
        }
      });
    }

    initBuild().then(() => {
      setTimeout(() => {
        buildJs();
      }, 2500);
    });
  }
};
