const chokidar = require('chokidar');
const express = require('express');
const app = express();

const jsRoute = '/assets/js/mythical-player.dist.js';

function tmplIndex() {
  return String.raw`
    <!DOCTYPE html>
    <html lang="en">
      <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <meta http-equiv="X-UA-Compatible" content="ie=edge">
        <title>mythical-player</title>
      </head>
      <body>
      <div style="display: flex; justify-content: center; width: 100%;">
        <div style="width: 96%; max-width: 960px">
          <div id="player-default" style="font-size: 62.5%"></div>
        </div>
      </div>
      <script src="${jsRoute}"></script>
      <script>
        fetch('/assets/media/playlist.json')
          .then(response => response.json())
          .then(playlist => {
            MythicalPlayer({
              placeholder: document.getElementById('player-default'),
              props: {
                style: {
                  ambient: 'dark',
                  accent: 'blue',
                  height: '620px',
                  trackInfoHorizontal: 'left'
                },
                playlist,
                useShadowDOM: true,
                list: {
                  showCovers: true,
                  showTrackNumber: true,
                  showIconIsPlaying: true,
                  showFileExtension: true
                },
                id: 'default'
              }
            });
          });
      </script>
      </body>
    </html>
  `;
}

app.get('/', (req, res) => {
  res.send(tmplIndex());
});
app.get(jsRoute, (req, res) => {
  res.sendFile('bundle/mythical-player.dist.js', {
    root: __dirname
  });
});
app.use('/assets/media', express.static(process.env.MEDIA_FOLDER));

const port = process.env.PORT;
app.listen(port, () => {
  console.log(`Example app listening on port ${port}`);
});

const watcher = chokidar.watch(['js', 'sass'], {
  ignored: (path, stats) =>
    stats?.isFile() && !path.endsWith('.scss') && !path.endsWith('.js'),
  persistent: true
});
watcher.on('change', (path, stats) => {
  if (stats) console.log(`File ${path} changed`);
  require('./build.js').buildJs();
});
